@@ -1,26 +1,26 @@
-# Copyright 2004-2019, Paul Johnson (paul@pjcj.net)
+# Copyright 2004-2025, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
 # The latest version of this software should be available from my homepage:
-# http://www.pjcj.net
+# https://pjcj.net
 
 package Devel::Cover::Subroutine;
 
 use strict;
 use warnings;
 
-our $VERSION = '1.36'; # VERSION
+our $VERSION = '1.51'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
-sub uncoverable { $_[0][2]               }
-sub covered     { $_[0][0]               }
-sub total       { 1                      }
-sub percentage  { $_[0][0] ? 100 : 0     }
-sub error       { $_[0][0] xor !$_[0][2] }
-sub name        { $_[0][1]               }
-sub criterion   { "subroutine"           }
+sub uncoverable { $_[0][2] }
+sub covered     { $_[0][0] }
+sub total       { 1 }
+sub percentage  { $_[0][0] ? 100 : 0 }
+sub error       { $_[0]->simple_error }
+sub name        { $_[0][1] }
+sub criterion   { "subroutine" }
 
 1
 
@@ -28,15 +28,15 @@ __END__
 
 =head1 NAME
 
-Devel::Cover::Statement - Code coverage metrics for Perl
+Devel::Cover::Subroutine - Code coverage metrics for Perl subroutines
 
 =head1 VERSION
 
-version 1.36
+version 1.51
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Statement;
+ use Devel::Cover::Subroutine;
 
 =head1 DESCRIPTION
 
@@ -54,11 +54,11 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2004-2019, Paul Johnson (paul@pjcj.net)
+Copyright 2004-2025, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
 The latest version of this software should be available from my homepage:
-http://www.pjcj.net
+https://pjcj.net
 
 =cut
